import { redis } from "bun";
import { cassandra } from "#lib/database";

import type { ExtendedRequest, RouteDef } from "#types/server";

const routeDef: RouteDef = {
	method: "GET",
	accepts: "*/*",
	returns: "application/json",
};

async function handler(request: ExtendedRequest): Promise<Response> {
	const cassandraHealth = cassandra.getHealthStatus();
	const redisHealth = await redis
		.connect()
		.then(() => "healthy")
		.catch(() => "unhealthy");

	return Response.json({
		status: "healthy",
		timestamp: new Date().toISOString(),
		requestTime: `${(performance.now() - request.startPerf).toFixed(2)}ms`,
		services: {
			cassandra: cassandraHealth,
			redis: redisHealth,
		},
	});
}

export { handler, routeDef };
